==> fritzing_0.6.3b+dfsg.orig.tar.bz2: fritzing.2011.08.18.source/src/itemdrag.cpp <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 4183 $:
$Author: cohen@irascible.com $:
$Date: 2010-05-06 22:30:19 +0200 (Thu, 06 May 2010) $

********************************************************************/


#include "itemdrag.h"
#include "debugdialog.h"

ItemDrag * ItemDrag::singleton = new ItemDrag();

ItemDrag::ItemDrag(QObject * parent) :
	QObject(parent)
{
}

void ItemDrag::cleanup() {
	if (singleton) {
		delete singleton;
		singleton = NULL;
	}
}

QHash<QObject *, QObject *> & ItemDrag::cache() {
	return m_cache;
}

void ItemDrag::dragIsDone() {
	m_cache.clear();
	emit dragIsDoneSignal(this);
}

QHash<QObject *, QObject *> & ItemDrag::_cache() {
	return singleton->m_cache;
}


ItemDrag * ItemDrag::_itemDrag() {
	return singleton;
}

void ItemDrag::_dragIsDone() {
	singleton->dragIsDone();
}

==> fritzing_0.7.4b+dfsg.orig.tar.bz2: fritzing-0.7.4b.source/src/itemdrag.cpp <==
/*******************************************************************

Part of the Fritzing project - http://fritzing.org
Copyright (c) 2007-2010 Fachhochschule Potsdam - http://fh-potsdam.de

Fritzing is free software: you can redistribute it and/or modify
it under the terms of the GNU General Public License as published by
the Free Software Foundation, either version 3 of the License, or
(at your option) any later version.

Fritzing is distributed in the hope that it will be useful,
but WITHOUT ANY WARRANTY; without even the implied warranty of
MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
GNU General Public License for more details.

You should have received a copy of the GNU General Public License
along with Fritzing.  If not, see <http://www.gnu.org/licenses/>.

********************************************************************

$Revision: 5783 $:
$Author: cohen@irascible.com $:
$Date: 2012-01-26 07:31:21 +0100 (Thu, 26 Jan 2012) $

********************************************************************/


#include "itemdrag.h"
#include "debugdialog.h"

ItemDrag * ItemDrag::Singleton = new ItemDrag();

ItemDrag::ItemDrag(QObject * parent) :
	QObject(parent)
{
}

void ItemDrag::__dragIsDone() {
	m_cache.clear();
	emit dragIsDoneSignal(this);
}

void ItemDrag::cleanup() {
	if (Singleton) {
		delete Singleton;
		Singleton = NULL;
	}
}

QHash<QObject *, QObject *> & ItemDrag::cache() {
	return Singleton->m_cache;
}

ItemDrag * ItemDrag::singleton() {
	return Singleton;
}

void ItemDrag::dragIsDone() {
	Singleton->__dragIsDone();
}

void ItemDrag::setOriginator(QWidget * originator) {
	Singleton->m_originator = originator;
}

QWidget* ItemDrag::originator() {
	return Singleton->m_originator;
}
